Intel471Ex.Downloader (intel471_ex v0.1.0)
File downloader for Intel 471 Titan API using Req.
Summary
Functions
Downloads a file from Intel 471 Titan API.
Downloads a file from Intel 471 Titan API and automatically extracts the filename from the URL.
Functions
@spec download_file(String.t(), String.t(), map(), map() | nil) :: {:ok, String.t()} | {:error, any()}
Downloads a file from Intel 471 Titan API.
Parameters
url: Full URL to the file (e.g., "https://api.intel471.com/v1/dataleak/download/archives/interlock/25154/structure.zip")destination: Local path where the file should be savedparams: Query parameters (optional)config: Optional configuration override
Returns
{:ok, path}- Successful download with path to saved file{:error, reason}- Error with reason
@spec download_file_auto(String.t(), String.t(), map(), map() | nil) :: {:ok, String.t()} | {:error, any()}
Downloads a file from Intel 471 Titan API and automatically extracts the filename from the URL.
Parameters
url: Full URL to the filedestination_dir: Directory where the file should be saved (default: "downloads")params: Query parameters (optional)config: Optional configuration override
Returns
{:ok, path}- Successful download with path to saved file{:error, reason}- Error with reason